@@ -18,7 +18,7 @@ except ImportError:
 try:
 	from PyQt4.QtGui import *
 	from PyQt4.QtCore import *
-	from view import EdView, EdViewRW, ResView, FileView, CallView, ClassGraphView, DebugView, CodemarkView
+	from view import EdView, EdViewRW, ResView, FileView, CallView, ClassGraphView, FileFuncGraphView, DebugView, CodemarkView, CodeContextView
 	import backend
 	from backend.plugins import PluginHelper
 	import DialogManager
@@ -33,12 +33,13 @@ class SeascopeApp(QMainWindow):
 		ev_font = QFont()
 		ev_font.fromString(self.edit_book.ev_font)
 		res = DialogManager.show_preferences_dialog(self.app_style, self.edit_ext_cmd, ev_font, self.exit_dont_ask, self.inner_editing, self.eb_is_show_line)
-		(self.app_style, self.app_font, self.edit_ext_cmd, ev_font, self.exit_dont_ask, self.inner_editing, self.eb_is_show_line) = res
+		(self.app_style, self.app_font, self.edit_ext_cmd, ev_font, self.exit_dont_ask, self.inner_editing_conf, self.eb_is_show_line) = res
 		if self.edit_ext_cmd != None:
 			self.edit_ext_cmd = str(self.edit_ext_cmd).strip()
 		if (self.edit_ext_cmd == None or self.edit_ext_cmd == ''):
 			self.edit_ext_cmd = 'x-terminal-emulator -e vim %F +%L'
 		self.edit_book.change_ev_font(ev_font.toString())
+		self.code_ctx_view.change_ev_font(ev_font.toString())
 		self.edit_book.show_line_number_pref(self.eb_is_show_line)
 		self.app_write_config()
 
@@ -63,10 +64,11 @@ class SeascopeApp(QMainWindow):
 		if not DialogManager.show_yes_no('Restart ?'):
 			return
 		hint = self.edit_book.get_file_line_list()
-		self.proj_close_cb()
+		if backend.proj_is_open():
+			self.proj_close_cb()
 		QApplication.quit()
 		os.environ['SEASCOPE_RESTART_HINT'] = '%s' % str(hint)
-		QProcess.startDetached(sys.executable, QApplication.arguments());
+		QProcess.startDetached(sys.executable, QApplication.arguments(), self.seascope_start_dir);
 	def file_restarted_cb(self):
 		try:
 			hint = os.environ['SEASCOPE_RESTART_HINT']
@@ -281,7 +283,9 @@ class SeascopeApp(QMainWindow):
 		self.toolbar.addAction(si(QStyle.SP_MediaSkipBackward), 'Previous Position', self.go_prev_pos_cb)
 		self.toolbar.addAction(si(QStyle.SP_MediaSkipForward), 'Next Position', self.go_next_pos_cb)
 		self.toolbar.addSeparator()
-		self.toolbar.addAction(QIcon('icons/codeview.png'), 'Code Quick View', self.is_code_quick_view)
+		self.code_ctx_view_act = self.toolbar.addAction(QIcon('icons/codeview.png'), 'Code Quick View', self.code_ctx_view_act_cb)
+		self.code_ctx_view_act.setCheckable(True)
+		self.code_ctx_view_act.setChecked(self.is_show_code_ctx_view)
 	
 		
 	# app config
@@ -298,6 +302,7 @@ class SeascopeApp(QMainWindow):
 		self.inner_editing_conf = False
 		self.inner_editing = False
 		self.is_show_toolbar = False
+		self.is_show_code_ctx_view = False
 		self.edit_ext_cmd = 'x-terminal-emulator -e vim %F +%L'
 		self.eb_is_show_line = False
 
@@ -417,6 +422,7 @@ class SeascopeApp(QMainWindow):
 		self.res_book.clear()
 		self.file_view.clear()
 		self.cm_mgr.clear()
+		self.code_ctx_view.clear()
 
 	def proj_settings_cb(self):
 		backend.proj_settings_trigger()
@@ -449,13 +455,17 @@ class SeascopeApp(QMainWindow):
 
 	def show_toolbar_cb(self):
 		self.is_show_toolbar = self.show_toolbar.isChecked()
-		if (self.is_show_toolbar):
+		if self.is_show_toolbar:
 			self.create_toolbar()
 		else:
 			self.removeToolBar(self.toolbar)
 
-	def is_code_quick_view(self):
-		QMessageBox.information(None, "Seascope", 'Not implemented yet!', QMessageBox.Ok)
+	def code_ctx_view_act_cb(self):
+		self.is_show_code_ctx_view = self.code_ctx_view_act.isChecked()
+		if self.is_show_code_ctx_view:
+			self.code_ctx_view.show()
+		else:
+			self.code_ctx_view.hide()
 
 	def connect_signals(self):
 		self.edit_book.sig_history_update.connect(self.res_book.history_update)
@@ -464,6 +474,25 @@ class SeascopeApp(QMainWindow):
 		self.file_view.sig_show_file.connect(self.edit_book.show_file)
 		self.edit_book.sig_open_dir_view.connect(self.file_view.open_dir_view)
 		self.edit_book.sig_file_closed.connect(self.codemark_del_file_cb)
+		self.edit_book.sig_editor_text_selected.connect(self.editor_text_selected)
+		self.code_ctx_view.sig_codecontext_showfile.connect(self.code_context_showfile_cb)
+		
+	def editor_text_selected(self, text):
+		if self.is_show_code_ctx_view:
+			if not self.code_ctx_view.set_cur_query(text):
+				return
+			rquery = {}
+			rquery['cmd'] = 'DEF'
+			rquery['req'] = str(text)
+			rquery['opt'] = None
+			sig_res = backend.prj.qry.query(rquery)
+			sig_res[0].connect(self.code_ctx_view_query_res_cb)
+
+	def code_ctx_view_query_res_cb(self, sym, res):
+		self.code_ctx_view.showResult(sym, res)
+	
+	def code_context_showfile_cb(self, filename, line):
+		self.show_file_line(filename, line)
 
 	def setup_widget_tree(self):
 		self.hsp = QSplitter();
@@ -475,8 +504,14 @@ class SeascopeApp(QMainWindow):
 		self.vsp.setOrientation(Qt.Vertical)
 		self.vsp.addWidget(self.hsp)
 		self.vsp.addWidget(self.res_book)
-		self.vsp.setSizes([1, 1])
-
+		self.hsp_res = QSplitter();
+		self.hsp_res.addWidget(self.res_book)
+		self.hsp_res.addWidget(self.code_ctx_view)
+		self.vsp.addWidget(self.hsp_res)
+		
+		self.hsp_res.setSizes([200, 1])
+		self.vsp.setSizes([1, 60])
+		
 		self.setCentralWidget(self.vsp)
 		self.setWindowTitle('Seascope')
 		self.setGeometry(300, 100, 800, 600)
@@ -488,7 +523,8 @@ class SeascopeApp(QMainWindow):
 		self.edit_book.is_show_line = self.eb_is_show_line
 		self.edit_book.m_show_line_num.setChecked(self.edit_book.is_show_line)
 		if (self.ev_font):
-			self.edit_book.ev_font = self.ev_font	
+			self.edit_book.ev_font = self.ev_font
+			self.code_ctx_view.ev_font = self.ev_font
 		self.show_toolbar.setChecked(self.is_show_toolbar)
 
 	def create_widgets(self):
@@ -500,6 +536,8 @@ class SeascopeApp(QMainWindow):
 		self.res_book  = ResView.ResultManager()
 		self.file_view = FileView.FileTree()
 		self.cm_mgr    = CodemarkView.CodemarkManager()
+		self.code_ctx_view = CodeContextView.CodeContextViewManager()
+		self.code_ctx_view.hide()
 
 		self.sbar = self.statusBar()
 		self.create_mbar()
@@ -515,12 +553,14 @@ class SeascopeApp(QMainWindow):
 
 		CallView.CallTreeWindow.parent = self
 		ClassGraphView.ClassGraphWindow.parent = self
+		FileFuncGraphView.FileFuncGraphWindow.parent = self
 
 		PluginHelper.backend_menu = self.backend_menu
 		PluginHelper.edit_book = self.edit_book
 		PluginHelper.res_book = self.res_book
 		PluginHelper.call_view = CallView
 		PluginHelper.class_graph_view = ClassGraphView
+		PluginHelper.file_func_graph_view = FileFuncGraphView
 		PluginHelper.file_view = self.file_view
 		PluginHelper.dbg_view = DebugView
 		
@@ -532,8 +572,9 @@ class SeascopeApp(QMainWindow):
 			font.fromString(self.app_font)
 			QApplication.setFont(font)
 
-	def __init__(self, parent=None):
+	def __init__(self, parent=None, app_start_dir=None):
 		QMainWindow.__init__(self)
+		self.seascope_start_dir = app_start_dir
 
 		self.app_read_config()
 
@@ -543,8 +584,19 @@ class SeascopeApp(QMainWindow):
 		self.setup_widget_tree()
 		self.setup_style_and_font()
 
-		if len(self.recent_projects):
-			self.proj_open(self.recent_projects[0])
+		prj_path = None
+		args = QApplication.arguments()
+		if len(args) == 2:
+			prj_path = str(args[1])
+			if not os.path.isabs(prj_path):
+				dname = self.seascope_start_dir
+				prj_path = os.path.join(dname, prj_path)
+			
+		if not prj_path or os.getenv('SEASCOPE_RESTART_HINT'):
+			if len(self.recent_projects):
+				prj_path = self.recent_projects[0]
+		if prj_path:
+			self.proj_open(prj_path)
 		#else:
 			#self.proj_open_cb()
 		self.file_restarted_cb()
@@ -558,14 +610,17 @@ if __name__ == "__main__":
 		sys.exit(-1)
 
 	# change working dir to the script dir so that we can run this script anywhere else
+	app_start_dir = os.getcwd()
 	app_dir = os.path.dirname(os.path.realpath(__file__))
 	os.chdir(app_dir)
 	
+	# load plugins
 	backend.load_plugins()
 	view.load_plugins()
 
+	# start app
 	app = QApplication(sys.argv)
-	ma = SeascopeApp()
+	ma = SeascopeApp(app_start_dir=app_start_dir)
 	ma.show()
 	ret = app.exec_()
 	sys.exit(ret)
